/******************************************************************************************
Description: 	Stored Process to diagnose a ddcf plan

Creation Date: 	March 2011

Modified Date : April - Added macro call for Model table

Input parameters : 
NOTE:

ddcf_hpf_engine.sas file is present as uncompiled macro for customization purpose.
If necessary, the 'STOCHASTIC' statement can be replaced by 'CONTROL' statement as given in the uncompiled version.
It can be saved in the server and the 'path of stored process file' needs to be included in the '%include' statement below and line should be uncommented.
The EXTEND option can be changed from 'AVERAGE' to NONE, FIRST, LAST, MEDIAN, STOCHASTIC, MINIMUM, MAXIMUM.
***********************************************************************************************/
/*%include "path of stored process file\ddcf_hpf_engine.sas";*/

/*options mlogic mprint symbolgen;*/


%macro ddcf_diagnose_forecast_plan;

/*Assign transaction server library*/
%ddcf_assign_trans_library(libref=uiart);


%global adhoc_process_flg PLAN_VALID_DATA_FLG;
%let adhoc_process_flg=&GL_SHORT_YES.;
%local plan_status ;

%Global rediagnose_flg;

%global call_from_forecast;
%let call_from_forecast = &GL_SHORT_YES.;

/* Define connection string for transactional server*/
%ddcf_connect_to_trans_db;

		%global drive_nm FORECAST_METHOD;
		%let drive_nm = &GL_DATA_STORAGE_PATH.;
        %let FORECAST_METHOD = HPF;
        %ddcf_plan_spec;
	%ddcf_call_set_params_libnames;
    
	 		%let table_exist = %sysfunc(exist(_hpf0.est));
			%let table_exist1 = %sysfunc(exist(_hpf0.est0));
        
		/* GL_OPT_FLAG is always Y */
              %if &table_exist. eq 1 %then %do;
	              %let rediagnose_flg = 1;
	          %end;
			  %else %if &table_exist1. eq 1 %then %do;
                  %let rediagnose_flg = 1;
			  %end;
			  %else %do;
                  %let rediagnose_flg = 0;
			  %end;


/* added for retain model functionality */
	%if &rediagnose_flg=0 or &rediagnose_flg=1 %then %do;
			data control.plan_valid_data_flg&plan_id.;
			set control.plan_valid_data_flg&plan_id.;
			incre_fcst_flag = "&gl_short_no.";
			run;
	%end;

/* Update plan and time series specific parameter in hpf_preference&plan_id table*/
%ddcf_update_hpf_param_for_proc 

  option autosignon=YES sascmd="!sascmd";

/* Forecasting Store Proc */

/* added to handle multiple parallel processing */
/*%ddcf_bef_ent_mp_connect(lib =uiart , file =connect_flg , column =flag );*/

%ddcf_call_diagnose_engine_mac;

/* Only in case, the optimization flag is set to Y, signoff is required.*/
 
/* %ddcf_signoff_statements;*/

/* %ddcf_immediate_after(lib =uiart , file = connect_flg, column = flag); */

/* Reconcile Store Proc */
%ddcf_call_reconcile_mac;

/*Deleting work tables*/
proc datasets lib=work kill nolist nowarn memtype = (data view);
run; 
quit;


		%global drive_nm FORECAST_METHOD;
		%let drive_nm = &GL_DATA_STORAGE_PATH.;
        %let FORECAST_METHOD = HPF;

	%ddcf_call_set_params_libnames;

/*Updating UIARTs*/
	%put "new code";
%ddcf_uiart_diag_fcst_plan_stp;

%if &GL_FAW_POSTGRES_IND. ne 1 %then %do;
	libname uiart clear;
%end;

/*Deleting work tables*/
proc datasets lib=work kill nolist nowarn memtype = (data view);
run; 
quit;

%mend ddcf_diagnose_forecast_plan;

%ddcf_init;
%ddcf_capture_log(logprefix=diagnose_forecast,log_id=&plan_id.);

%ddcf_diagnose_forecast_plan;

%ddcf_reset_log;
