/**********************************************************************************************
/*-- Copyright (c) 2013 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	Forecast Analyst Workbench 5.2
Subject Area  	Plan exploration
Name          	FAW 5.2:ddcf_create_consensus_plan  
Purpose			Stored Process for executing consensus plan.  

Created by 		Shikha Agrawal
Creation Date   20-Jul-2013 

* Copyright (c) 2013 by SAS Institute Inc., Cary, NC 27513

Input Parameters required

1. consensus_plan_id : Sample Value 1
2. Run_Mode 		 : 0 - Create 
			  		   1 - Edit 
			  		   2 - Refresh
3. Prev_staus 		 : This is optional parameter. Values in this parameter passed 
					   only in refresh and edit consensus plan. 

***********************************************************************************************/
/*%let consensus_plan_id =4 ;*/
/*  %let run_mode = 0;*/
/*  %let prev_status = 0;*/


/*options mprint mlogic symbolgen; */
%macro ddcf_create_consensus_plan;
%global err_status_ind job_rc job_rc_msg;


%let job_rc = 0;
%let err_status_ind =0;
%let job_rc_msg = ; 

	%ddcf_get_cons_plan_dtls;
	/*If error in previous macro then exit*/
	%if &job_rc. > 4 %then %do;
		%let err_status_ind =1;
		%goto exit;
	%end;

	%ddcf_cons_plan_dim_dtls
	/*If error in previous macro then exit*/
	%if &job_rc. > 4 %then %do;
		%let err_status_ind =1;
		%goto exit;
	%end;

	%ddcf_cons_def_time_sett_var
	/*If error in previous macro then exit*/
	%if &job_rc. > 4 %then %do;
		%let err_status_ind =1;
		%goto exit;
	%end;
	
	%ddcf_cons_plan_fact_tab
	/*If error in previous macro then exit*/
	%if &job_rc. > 4 %then %do;
		%let err_status_ind =1;
		%goto exit;
	%end;


	%if &err_status_ind. eq 0 %then %do;
		/* Creates dim tables for consensus plan */
		%ddcf_cons_plan_dim_tables
		/*If error in previous macro then exit*/
		%if &job_rc. > 4 %then %do;
			%let err_status_ind =1;
			%goto exit;
		%end;

		%ddcf_cons_plan_adhoc_dim_tables;
		/*If error in previous macro then exit*/
		%if &job_rc. > 4 %then %do;
			%let err_status_ind =1;
			%goto exit;
		%end;


		%ddcf_cons_plan_time_dim_tab;
		/*If error in previous macro then exit*/
		%if &job_rc. > 4 %then %do;
			%let err_status_ind =1;
			%goto exit;
		%end;

		%ddcf_load_planexpl_anal_var;
		/*If error in previous macro then exit*/
		%if &job_rc. > 4 %then %do;
			%let err_status_ind =1;
			%goto exit;
		%end;

		
	%end;

%exit:

	/* Plan Created */
	%if &err_status_ind= 0 %then %do;
		%if &run_mode. eq 1 or &run_mode. eq 2 %then %do;
			/* If previous status is created, error_in_create, no_data_found or error_in_refresh and data is not sent to FM */
			%if (&prev_status. eq 1 or &prev_status. eq 2 or &prev_status. eq 23 or &prev_status. eq 30) and
				(&data_exist_in_fm_ind. ne 1) %then %do;
				/* Created */
				%let consensus_status= 1;
			%end;
			%else %do;
				/*	initialized  */
				%let consensus_status= 3;
			%end;
		%end;
		%else %do;
			/* setting status plan created */		
			%let consensus_status= 1;
		%end;
	%end;
	/* Failed*/
	%else %if &err_status_ind = 1 %then %do;
		%if  &run_mode. eq 2 %then %do;
			/* setting status CONSENSUS_ERROR_IN_REFRESH  */	
			%let consensus_status = 30;
		%end;
		%else %do;
			/* setting status ERROR_IN_CREATION */	
			%let consensus_status = 2;
		%end;
	%end;
	/* No Data for the corresponding planning date*/
	%else  %if &err_status_ind= 2 %then %do;
		%let consensus_status = 23;
	%end;

	/* Update the consensus status in uiart.consensus_plan_details table*/
	proc sql noprint;
		update uiart.consensus_plan_details 
		set consensus_status_no = &consensus_status.
		where consensus_plan_id = &consensus_plan_id.
		;
	quit;

	%ddcf_clear_work_lib;

%mend;

%ddcf_init;

%ddcf_capture_log(logprefix=create_consensus_plan,log_id = &consensus_plan_id.);

%ddcf_create_consensus_plan;

%ddcf_reset_log;
